@@ -20,7 +20,7 @@
 package users
 
 /*
-#cgo CFLAGS: -W -Wall -g  -fstack-protector-strong -D_FORTITY_SOURCE=1 -fPIC
+#cgo CFLAGS: -W -Wall -g  -fstack-protector-all -fPIC
 #cgo LDFLAGS: -lcrypt
 
 #include <stdlib.h>
