@@ -20,7 +20,7 @@
 package appearance
 
 import (
-	"pkg.deepin.io/lib/locale"
+	"github.com/linuxdeepin/go-lib/locale"
 )
 
 // key is locale code
