@@ -30,12 +30,12 @@ import (
 	"time"
 
 	dbus "github.com/godbus/dbus"
+	"github.com/linuxdeepin/dde-daemon/common/dsync"
 	gio "github.com/linuxdeepin/go-gir/gio-2.0"
 	"github.com/linuxdeepin/go-lib/dbusutil"
 	"github.com/linuxdeepin/go-lib/dbusutil/gsprop"
 	"github.com/linuxdeepin/go-lib/pulse"
 	"golang.org/x/xerrors"
-	"github.com/linuxdeepin/dde-daemon/common/dsync"
 )
 
 const (
@@ -213,7 +213,7 @@ func newAudio(service *dbusutil.Service) *Audio {
 	return a
 }
 
-func startPulseaudio() error {
+func startPulseaudio(count int) error {
 	var errBuf bytes.Buffer
 	cmd := exec.Command(cmdSystemctl, "--user", "start", "pulseaudio")
 	cmd.Stderr = &errBuf
@@ -225,18 +225,16 @@ func startPulseaudio() error {
 	errBuf.Reset()
 
 	err = exec.Command(cmdPulseaudio, "--check").Run()
-	if err == nil {
-		return nil
+	if err != nil {
+		logger.Warning("pulseaudio check error", err)
+		if count > 0 {
+			logger.Info("retry start pulseaudio after 500ms")
+			time.Sleep(500 * time.Millisecond)
+			return startPulseaudio(count - 1)
+		}
+		return errors.New("failed to start pulseaudio")
 	}
 
-	cmd = exec.Command(cmdPulseaudio, "--start")
-	cmd.Stderr = &errBuf
-	err = cmd.Run()
-	if err != nil {
-		logger.Warningf("failed to start pulseaudio via `pulseaudio --start`: err: %v, stderr: %s",
-			err, errBuf.Bytes())
-		return xerrors.Errorf("cmd `pulseaudio --start` error: %w", err)
-	}
 	return nil
 }
 
@@ -413,6 +411,11 @@ func (a *Audio) shouldAutoPause() bool {
 		return false
 	}
 
+	logger.Debugf("default sink active port: %v %v", port.Name, port.Available)
+	if a.defaultSink.ActivePort.Available == 1 {
+		return false
+	}
+
 	switch DetectPortType(card.core, &port) {
 	case PortTypeBluetooth, PortTypeHeadset, PortTypeLineIO:
 		return true
@@ -957,10 +960,12 @@ func (a *Audio) resetSinksVolume() {
 func (a *Audio) resetSourceVolume() {
 	logger.Debug("reset source volume", defaultInputVolume)
 	for _, s := range a.ctx.GetSourceList() {
-		a.ctx.SetSourceMuteByIndex(s.Index, false)
-		cv := s.Volume.SetAvg(defaultInputVolume).SetBalance(s.ChannelMap,
-			0).SetFade(s.ChannelMap, 0)
-		a.ctx.SetSourceVolumeByIndex(s.Index, cv)
+		if s.ActivePort.Name != "" {
+			a.ctx.SetSourceMuteByIndex(s.Index, false)
+			cv := s.Volume.SetAvg(defaultInputVolume).SetBalance(s.ChannelMap,
+				0).SetFade(s.ChannelMap, 0)
+			a.ctx.SetSourceVolumeByIndex(s.Index, cv)
+		}
 	}
 }
 
@@ -1013,6 +1018,10 @@ func (a *Audio) resumeSinkConfig(s *Sink) {
 		logger.Warning("nil sink")
 		return
 	}
+	if s.ActivePort.Name == "" {
+		logger.Debug("no active port")
+		return
+	}
 
 	logger.Debugf("resume sink %s %s", a.getCardNameById(s.Card), s.ActivePort.Name)
 	_, portConfig := GetConfigKeeper().GetCardAndPortConfig(a.getCardNameById(s.Card), s.ActivePort.Name)
@@ -1042,6 +1051,10 @@ func (a *Audio) resumeSourceConfig(s *Source, isPhyDev bool) {
 		logger.Warning("nil source")
 		return
 	}
+	if s.ActivePort.Name == "" {
+		logger.Debug("no active port")
+		return
+	}
 
 	logger.Debugf("resume source %s %s", a.getCardNameById(s.Card), s.ActivePort.Name)
 	_, portConfig := GetConfigKeeper().GetCardAndPortConfig(a.getCardNameById(s.Card), s.ActivePort.Name)
