@@ -4,8 +4,8 @@ import (
 	"flag"
 	"time"
 
-	"pkg.deepin.io/lib/dbusutil"
-	"pkg.deepin.io/lib/log"
+	"github.com/linuxdeepin/go-lib/dbusutil"
+	"github.com/linuxdeepin/go-lib/log"
 )
 
 var noQuitFlag bool
