@@ -19,13 +19,13 @@
 
 package bluetooth
 
-import . "pkg.deepin.io/lib/gettext"
+import . "github.com/linuxdeepin/go-lib/gettext"
 
 type profile struct {
 	uuid, name string
 }
 
-// nolint
+//nolint
 var profiles = []profile{
 	profile{SPP_UUID, Tr("Serial port")},
 	profile{DUN_GW_UUID, Tr("Dial-Up networking")},
