@@ -69,7 +69,6 @@ type Manager struct {
 	oneFingerLeftEnable   bool
 	oneFingerRightEnable  bool
 	configManagerPath     dbus.ObjectPath
-	enabled               bool
 	sessionWatcher        sessionwatcher.SessionWatcher
 }
 
@@ -144,14 +143,14 @@ func newManager() (*Manager, error) {
 	}
 
 	systemConnObj := systemConn.Object(configManagerId, "/")
-	err = systemConnObj.Call(configManagerId+".acquireManager", 0, "dde-session-daemon", "gesture", "").Store(&m.configManagerPath)
+	err = systemConnObj.Call(configManagerId+".acquireManager", 0, "org.deepin.dde.daemon", "org.deepin.dde.daemon.gesture", "").Store(&m.configManagerPath)
 	if err != nil {
 		logger.Warning(err)
 	}
-	m.longPressEnable = m.getGestureConfigValue("long-press-enable")
-	m.oneFingerBottomEnable = m.getGestureConfigValue("one-finger-bottom-enable")
-	m.oneFingerLeftEnable = m.getGestureConfigValue("one-finger-left-enable")
-	m.oneFingerRightEnable = m.getGestureConfigValue("one-finger-right-enable")
+	m.longPressEnable = m.getGestureConfigValue("longPressEnable")
+	m.oneFingerBottomEnable = m.getGestureConfigValue("oneFingerBottomEnable")
+	m.oneFingerLeftEnable = m.getGestureConfigValue("oneFingerLeftEnable")
+	m.oneFingerRightEnable = m.getGestureConfigValue("oneFingerRightEnable")
 
 	m.gesture = gesture.NewGesture(systemConn)
 	m.systemSigLoop = dbusutil.NewSignalLoop(systemConn, 10)
@@ -236,10 +235,10 @@ func (m *Manager) init() {
 		Name: "org.desktopspec.ConfigManager.Manager.valueChanged",
 	}, func(sig *dbus.Signal) {
 		if strings.Contains(string(sig.Name), "org.desktopspec.ConfigManager.Manager.valueChanged") {
-			m.longPressEnable = m.getGestureConfigValue("long-press-enable")
-			m.oneFingerBottomEnable = m.getGestureConfigValue("one-finger-bottom-enable")
-			m.oneFingerLeftEnable = m.getGestureConfigValue("one-finger-left-enable")
-			m.oneFingerRightEnable = m.getGestureConfigValue("one-finger-right-enable")
+			m.longPressEnable = m.getGestureConfigValue("longPressEnable")
+			m.oneFingerBottomEnable = m.getGestureConfigValue("oneFingerBottomEnable")
+			m.oneFingerLeftEnable = m.getGestureConfigValue("oneFingerLeftEnable")
+			m.oneFingerRightEnable = m.getGestureConfigValue("oneFingerRightEnable")
 		}
 	})
 
@@ -331,6 +330,14 @@ func (m *Manager) init() {
 func (m *Manager) shouldIgnoreGesture(info *gestureInfo) bool {
 	// allow right button up when kbd grabbed
 	if (info.Event.Name != "touch right button" || info.Event.Direction != "up") && isKbdAlreadyGrabbed() {
+		// 多任务窗口下，不应该忽略手势操作
+		isShowMultiTask, err := m.wm.GetMultiTaskingStatus(0)
+		if err != nil {
+			logger.Warning(err)
+		} else if isShowMultiTask && info.Event.Name == "swipe" {
+			logger.Debug("should not ignore swipe event, because we are in multi task")
+			return false
+		}
 		logger.Debug("another process grabbed keyboard, not exec action")
 		return true
 	}
@@ -351,10 +358,6 @@ func (m *Manager) shouldIgnoreGesture(info *gestureInfo) bool {
 
 func (m *Manager) Exec(evInfo EventInfo) error {
 	if len(os.Getenv("WAYLAND_DISPLAY")) != 0 {
-		if !m.enabled {
-			logger.Debug("Gesture had been disabled or session inactive")
-			return nil
-		}
 		if !isSessionActive("/org/freedesktop/login1/session/self") {
 			active, err := m.sessionWatcher.IsActive().Get(0)
 			if err != nil || !active {
