@@ -1,8 +1,8 @@
 package grub_gfx
 
 import (
-	"pkg.deepin.io/dde/daemon/loader"
-	"pkg.deepin.io/lib/log"
+	"github.com/linuxdeepin/go-lib/log"
+	"github.com/linuxdeepin/dde-daemon/loader"
 )
 
 const moduleName = "grub-gfx"
@@ -18,7 +18,6 @@ func (*module) GetDependencies() []string {
 }
 
 func (d *module) Start() error {
-	logger.Debug("module start")
 	detectChange()
 	return nil
 }
