@@ -85,6 +85,12 @@ const ( // power按键事件的响应
 	powerActionShowUI
 )
 
+var _useWayland bool
+
+func setUseWayland(value bool) {
+	_useWayland = value
+}
+
 type Manager struct {
 	service *dbusutil.Service
 	// properties
@@ -171,6 +177,7 @@ const (
 )
 
 func newManager(service *dbusutil.Service) (*Manager, error) {
+	setUseWayland(strings.Contains(os.Getenv("XDG_SESSION_TYPE"), "wayland"))
 	conn, err := x.NewConn()
 	if err != nil {
 		return nil, err
@@ -192,7 +199,7 @@ func newManager(service *dbusutil.Service) (*Manager, error) {
 	m.sessionSigLoop = dbusutil.NewSignalLoop(sessionBus, 10)
 	m.systemSigLoop = dbusutil.NewSignalLoop(sysBus, 10)
 
-	if len(os.Getenv("WAYLAND_DISPLAY")) != 0 {
+	if _useWayland {
 		m.waylandOutputMgr = kwayland.NewOutputManagement(sessionBus)
 		m.login1Manager = login1.NewManager(sysBus)
 	}
@@ -240,7 +247,7 @@ func (m *Manager) init() {
 		m.handleKeyEventFromShutdownFront(changKey)
 	})
 
-	if len(os.Getenv("WAYLAND_DISPLAY")) != 0 {
+	if _useWayland {
 		if shouldUseDDEKwin() {
 			m.shortcutManager.AddSpecialToKwin(m.wm)
 			m.shortcutManager.AddSystemToKwin(m.gsSystem, m.wm)
@@ -307,12 +314,13 @@ func (m *Manager) init() {
 		logger.Warning(err)
 	}
 
-	if len(os.Getenv("WAYLAND_DISPLAY")) != 0 {
+	if _useWayland {
 		m.initHandlers()
 		m.clickNum = 0
 
-		go m.ListenGlobalAccel(sessionBus)
-		go m.ListenKeyboardEvent(sysBus)
+		go m.listenGlobalAccel(sessionBus)
+		go m.listenKeyboardEvent(sysBus)
+		go m.listenMouseEvent(sysBus)
 	}
 }
 
@@ -344,6 +352,10 @@ var kwinSysActionCmdMap = map[string]string{
 	"Calculator":         "calculator",          // XF86Calculator
 	"Search":             "search",              // XF86Search
 	"NotificationCenter": "notification-center", // Meta M
+
+	"ScreenshotScroll": "screenshot-scroll",
+	"ScreenshotOcr":    "screenshot-ocr",
+	"GlobalSearch":     "global-search",
 }
 
 var waylandMediaIdMap = map[string]string{
@@ -402,7 +414,7 @@ var waylandMediaIdMap = map[string]string{
 	"Switch kbd layout": "switch-kbd-layout",
 }
 
-func (m *Manager) ListenGlobalAccel(sessionBus *dbus.Conn) error {
+func (m *Manager) listenGlobalAccel(sessionBus *dbus.Conn) error {
 	err := sessionBus.Object("org.kde.kglobalaccel",
 		"/component/kwin").AddMatchSignal("org.kde.kglobalaccel.Component", "globalShortcutPressed").Err
 	if err != nil {
@@ -483,7 +495,7 @@ func (m *Manager) ListenGlobalAccel(sessionBus *dbus.Conn) error {
 	return nil
 }
 
-func (m *Manager) ListenKeyboardEvent(systemBus *dbus.Conn) error {
+func (m *Manager) listenKeyboardEvent(systemBus *dbus.Conn) error {
 	err := systemBus.Object("com.deepin.daemon.Gesture",
 		"/com/deepin/daemon/Gesture").AddMatchSignal("com.deepin.daemon.Gesture", "KeyboardEvent").Err
 	if err != nil {
@@ -507,7 +519,7 @@ func (m *Manager) ListenKeyboardEvent(systemBus *dbus.Conn) error {
 				}
 			}
 
-			if len(os.Getenv("WAYLAND_DISPLAY")) != 0 {
+			if _useWayland {
 				if key == CapslockKey && value == KeyPress {
 					m.handleKeyEventByWayland("capslock")
 				} else if key == NumlockKey && value == KeyPress {
@@ -519,6 +531,31 @@ func (m *Manager) ListenKeyboardEvent(systemBus *dbus.Conn) error {
 	return nil
 }
 
+func (m *Manager) listenMouseEvent(systemBus *dbus.Conn) error {
+	err := systemBus.Object("com.deepin.daemon.Gesture",
+		"/com/deepin/daemon/Gesture").AddMatchSignal("com.deepin.daemon.Gesture", "MouseEvent").Err
+	if err != nil {
+		logger.Warning(err)
+		return err
+	}
+	m.systemSigLoop.AddHandler(&dbusutil.SignalRule{
+		Name: "com.deepin.daemon.Gesture.MouseEvent",
+	}, func(sig *dbus.Signal) {
+		if len(sig.Body) > 1 {
+			if m.dpmsIsOff {
+				logger.Debug("MouseEvent: dpms on")
+				err := exec.Command("dde_wldpms", "-s", "On").Run()
+				if err != nil {
+					logger.Warningf("failed to exec dde_wldpms: %s", err)
+				} else {
+					m.dpmsIsOff = false
+				}
+			}
+		}
+	})
+	return nil
+}
+
 // 初始化 NumLock 数字锁定键状态
 func (m *Manager) initNumLockState(sysBus *dbus.Conn) {
 	// 从 gsettings 读取相关设置
@@ -554,10 +591,12 @@ func (m *Manager) initNumLockState(sysBus *dbus.Conn) {
 			logger.Warning("setNumLockState failed:", err)
 		}
 	} else {
-		if len(os.Getenv("WAYLAND_DISPLAY")) != 0 {
-			err := setNumLockWl(m.waylandOutputMgr, m.conn, nlState)
-			if err != nil {
-				logger.Warning("setNumLockWl failed:", err)
+		if _useWayland {
+			if saveStateEnabled {
+				err := setNumLockWl(m.waylandOutputMgr, m.conn, nlState)
+				if err != nil {
+					logger.Warning("setNumLockWl failed:", err)
+				}
 			}
 		} else {
 			if saveStateEnabled {
@@ -618,7 +657,7 @@ func (m *Manager) handleKeyEventFromLockFront(changKey string) {
 func (m *Manager) handleKeyEventByWayland(changKey string) {
 	action := shortcuts.GetAction(changKey)
 	var isWaylandGrabed bool = false
-	if len(os.Getenv("WAYLAND_DISPLAY")) != 0 {
+	if _useWayland {
 		isWaylandGrabed = true
 		if action.Type == shortcuts.ActionTypeShowNumLockOSD || action.Type == shortcuts.ActionTypeShowCapsLockOSD {
 			sessionBus, err := dbus.SessionBus()
@@ -686,7 +725,7 @@ func (m *Manager) handleKeyEventByWayland(changKey string) {
 	} else if action.Type == shortcuts.ActionTypeShowNumLockOSD {
 		var state NumLockState
 		if !isWaylandGrabed {
-			if len(os.Getenv("WAYLAND_DISPLAY")) != 0 {
+			if _useWayland {
 				sessionBus, err := dbus.SessionBus()
 				if err != nil {
 					return
@@ -735,7 +774,7 @@ func (m *Manager) handleKeyEventByWayland(changKey string) {
 
 		if !isWaylandGrabed {
 			var state CapsLockState
-			if len(os.Getenv("WAYLAND_DISPLAY")) != 0 {
+			if _useWayland {
 				sessionBus, err := dbus.SessionBus()
 				if err != nil {
 					return
