@@ -22,12 +22,14 @@ package network
 import (
 	"fmt"
 	"sort"
+	"strconv"
+	"strings"
 
 	dbus "github.com/godbus/dbus"
 	nmdbus "github.com/linuxdeepin/go-dbus-factory/org.freedesktop.networkmanager"
-	"pkg.deepin.io/dde/daemon/network/nm"
-	"pkg.deepin.io/lib/dbusutil"
-	. "pkg.deepin.io/lib/gettext"
+	"github.com/linuxdeepin/go-lib/dbusutil"
+	. "github.com/linuxdeepin/go-lib/gettext"
+	"github.com/linuxdeepin/dde-daemon/network/nm"
 )
 
 type connectionSlice []*connection
@@ -37,12 +39,13 @@ func (c connectionSlice) Less(i, j int) bool { return c[i].Id < c[j].Id }
 func (c connectionSlice) Swap(i, j int)      { c[i], c[j] = c[j], c[i] }
 
 type connection struct {
-	nmConn   *nmdbus.ConnectionSettings
+	nmConn   nmdbus.ConnectionSettings
 	connType string
 
-	Path dbus.ObjectPath
-	Uuid string
-	Id   string
+	Path    dbus.ObjectPath
+	Uuid    string
+	Id      string
+	IfcName string
 
 	// if not empty, the connection will only apply to special device,
 	// works for wired, wireless, infiniband, wimax devices
@@ -50,7 +53,8 @@ type connection struct {
 	ClonedAddress string
 
 	// works for wireless, olpc-mesh connections
-	Ssid string
+	Ssid   string
+	Hidden bool
 }
 
 func (m *Manager) initConnectionManage() {
@@ -77,6 +81,42 @@ func (m *Manager) initConnectionManage() {
 	}
 }
 
+func isTempWiredConnectionSettings(conn nmdbus.ConnectionSettings, cdata connectionData) (bool, error) {
+	connType := getSettingConnectionType(cdata)
+	if connType != nm.NM_SETTING_WIRED_SETTING_NAME {
+		return false, nil
+	}
+	// wired connection
+	autoConnect := getSettingConnectionAutoconnect(cdata)
+	autoConnectPriority := getSettingConnectionAutoconnectPriority(cdata)
+	if autoConnect && autoConnectPriority == -999 {
+		unsaved, err := conn.Unsaved().Get(0)
+		if err != nil {
+			return false, err
+		}
+		if unsaved {
+			return true, nil
+		}
+	}
+	return false, nil
+}
+
+func (m *Manager) deleteTempConnectionSettings(conn *connection, cdata connectionData) {
+	isTemp, err := isTempWiredConnectionSettings(conn.nmConn, cdata)
+	if err != nil {
+		logger.Warning(err)
+		return
+	}
+	if isTemp {
+		uuid := getSettingConnectionUuid(cdata)
+		logger.Debug("delete unsaved connection", conn.Path, uuid)
+		err = conn.nmConn.Delete(0)
+		if err != nil {
+			logger.Warningf("failed to delete connection %s: %v", conn.Path, err)
+		}
+	}
+}
+
 func (m *Manager) newConnection(cpath dbus.ObjectPath) (conn *connection, err error) {
 	conn = &connection{Path: cpath}
 	nmConn, err := nmNewSettingsConnection(cpath)
@@ -85,7 +125,10 @@ func (m *Manager) newConnection(cpath dbus.ObjectPath) (conn *connection, err er
 	}
 
 	conn.nmConn = nmConn
-	conn.updateProps()
+	cdata := conn.updateProps()
+	if cdata != nil {
+		m.deleteTempConnectionSettings(conn, cdata)
+	}
 
 	// connect signals
 	nmConn.InitSignalExt(m.sysSigLoop, true)
@@ -109,6 +152,7 @@ func (conn *connection) updateProps() connectionData {
 
 	conn.Uuid = getSettingConnectionUuid(cdata)
 	conn.Id = getSettingConnectionId(cdata)
+	conn.IfcName = getSettingConnectionInterfaceName(cdata)
 
 	switch getSettingConnectionType(cdata) {
 	case nm.NM_SETTING_GSM_SETTING_NAME, nm.NM_SETTING_CDMA_SETTING_NAME:
@@ -143,6 +187,7 @@ func (conn *connection) updateProps() connectionData {
 		} else {
 			conn.ClonedAddress = ""
 		}
+		conn.Hidden = getSettingWirelessHidden(cdata)
 	}
 	return cdata
 }
@@ -199,7 +244,7 @@ func (m *Manager) removeConnection(cpath dbus.ObjectPath) {
 }
 
 func (m *Manager) doRemoveConnection(conns connectionSlice, i int) connectionSlice {
-	logger.Infof("remove connection %#v", conns[i])
+	logger.Debugf("remove connection %#v", conns[i])
 	m.destroyConnection(conns[i])
 	copy(conns[i:], conns[i+1:])
 	conns = conns[:len(conns)-1]
@@ -216,7 +261,7 @@ func (m *Manager) updateConnection(cpath dbus.ObjectPath) {
 	m.connectionsLock.Lock()
 	defer m.connectionsLock.Unlock()
 	conn.updateProps()
-	logger.Infof("update connection %#v", conn)
+	logger.Debugf("update connection %#v", conn)
 	m.updatePropConnections()
 }
 
@@ -266,6 +311,9 @@ func (m *Manager) ensureUniqueConnectionExists(devPath dbus.ObjectPath, active b
 // ensureWiredConnectionExists will check if wired connection for
 // target device exists, if not, create one.
 func (m *Manager) ensureWiredConnectionExists(wiredDevPath dbus.ObjectPath, active bool) (cpath dbus.ObjectPath, exists bool, err error) {
+	m.connectionSettingsLock.Lock()
+	defer m.connectionSettingsLock.Unlock()
+
 	uuid := nmGeneralGetDeviceUniqueUuid(wiredDevPath)
 	logger.Debug("uuid:", uuid)
 
@@ -276,7 +324,7 @@ func (m *Manager) ensureWiredConnectionExists(wiredDevPath dbus.ObjectPath, acti
 	}
 
 	// try get uuid from active or available connection
-	existedUuid := getWiredDeviceConnectionUuid(wiredDevPath)
+	existedUuid := getNonTempWiredDeviceConnectionUuid(wiredDevPath)
 	logger.Debug("existed uuid:", existedUuid)
 	if existedUuid != "" {
 		cpath, err = nmGetConnectionByUuid(existedUuid)
@@ -292,13 +340,74 @@ func (m *Manager) ensureWiredConnectionExists(wiredDevPath dbus.ObjectPath, acti
 	if nmGeneralIsUsbDevice(wiredDevPath) {
 		id = nmGeneralGetDeviceDesc(wiredDevPath)
 	} else {
-		id = Tr("Wired Connection")
+		id = m.getCreateConnectionName()
 	}
-	cpath, err = newUnsavedWiredConnectionForDevice(id, uuid, wiredDevPath, active)
+	cpath, err = newWiredConnectionForDevice(id, uuid, wiredDevPath, active)
 	return
 }
 
-func getConnectionUUID(connPath dbus.ObjectPath) (uuid string, err error) {
+// lock connection
+func (m *Manager) getCreateConnectionName() string {
+	m.connectionsLock.Lock()
+	defer m.connectionsLock.Unlock()
+	// get all wired connection
+	wiredConnSl := m.connections[deviceEthernet]
+	var numSl []int
+	// add 0, make sure at least elem
+	numSl = append(numSl, 0)
+	// get all connection index
+	for _, conn := range wiredConnSl {
+		// if current id dont contains Tr, ignore
+		if !strings.Contains(conn.Id, Tr("Wired Connection")) {
+			continue
+		}
+		// trim left, " 1"
+		numStr := strings.TrimLeft(conn.Id, Tr("Wired Connection"))
+		// id is Wired Connection, add 0 to sl
+		if numStr == "" {
+			numSl = append(numSl, 0)
+			continue
+		}
+		// trim " "
+		numStr = strings.Trim(numStr, " ")
+		// convert num string to int
+		num, err := strconv.Atoi(numStr)
+		// could fail here, such as id is "Wired Connection A/B"
+		if err != nil {
+			logger.Debugf("connection index convert unexpected happens %v", err)
+			continue
+		}
+		// append
+		numSl = append(numSl, num)
+	}
+
+	// sort num sl
+	sort.Ints(numSl)
+
+	logger.Debugf("num Sl is %v", numSl)
+
+	var num int
+	for index := 0; index < len(numSl); index++ {
+		// already in the last one, such as numSl is [0,0], num is  0+1
+		if index == len(numSl)-1 {
+			num = numSl[index] + 1
+			break
+		}
+		// check if equal next or larger
+		if numSl[index] == numSl[index+1] || numSl[index]+1 == numSl[index+1] {
+			continue
+		}
+		num = numSl[index] + 1
+		break
+	}
+
+	name := fmt.Sprintf(Tr("Wired Connection %v"), num)
+	logger.Debugf("create name is %v", name)
+
+	return name
+}
+
+func isTempWiredConnectionPath(connPath dbus.ObjectPath) (isTemp bool, uuid string, err error) {
 	connSettings, err := nmNewSettingsConnection(connPath)
 	if err != nil {
 		return
@@ -307,39 +416,44 @@ func getConnectionUUID(connPath dbus.ObjectPath) (uuid string, err error) {
 	if err != nil {
 		return
 	}
-
-	uuid = getSettingConnectionUuid(cdata)
+	isTemp, err = isTempWiredConnectionSettings(connSettings, cdata)
+	if err != nil {
+		return
+	}
+	if !isTemp {
+		uuid = getSettingConnectionUuid(cdata)
+	}
 	return
 }
 
-func getWiredDeviceConnectionUuid(wiredDevPath dbus.ObjectPath) string {
+func getNonTempWiredDeviceConnectionUuid(wiredDevPath dbus.ObjectPath) string {
 	wired, _ := nmNewDevice(wiredDevPath)
 	if wired == nil {
 		return ""
 	}
 
-	apath, err := wired.ActiveConnection().Get(0)
+	apath, err := wired.Device().ActiveConnection().Get(0)
 	if err == nil && isObjPathValid(apath) {
 		aConn, _ := nmNewActiveConnection(apath)
 		if aConn != nil {
 			connPath, err := aConn.Connection().Get(0)
 			if err == nil && isObjPathValid(connPath) {
-				uuid, err := getConnectionUUID(connPath)
-				if err == nil {
+				isTemp, uuid, err := isTempWiredConnectionPath(connPath)
+				if err == nil && !isTemp {
 					return uuid
 				}
 			}
 		}
 	}
 
-	connPaths, _ := wired.AvailableConnections().Get(0)
+	connPaths, _ := wired.Device().AvailableConnections().Get(0)
 	for _, connPath := range connPaths {
 		if !isObjPathValid(connPath) {
 			continue
 		}
 
-		uuid, err := getConnectionUUID(connPath)
-		if err == nil {
+		isTemp, uuid, err := isTempWiredConnectionPath(connPath)
+		if err == nil && !isTemp {
 			return uuid
 		}
 	}
@@ -452,6 +566,29 @@ func (m *Manager) activateConnection(uuid string, devPath dbus.ObjectPath) (cpat
 				return
 			}
 		}
+	} else {
+		// check if support multi connections
+		service := getSettingVpnServiceType(connData)
+		multi, ok := m.multiVpn[service]
+		// if not support, should close old one first
+		var multiUuid string
+		if !multi || !ok {
+			m.activeConnectionsLock.Lock()
+			// looking for vpn uuid
+			for _, actCon := range m.activeConnections {
+				// check if type is the same
+				if actCon.vpnType != service {
+					continue
+				}
+				// save uuid
+				multiUuid = actCon.Uuid
+				break
+			}
+			m.activeConnectionsLock.Unlock()
+		}
+		if multiUuid != "" {
+			m.deactivateConnection(multiUuid)
+		}
 	}
 
 	_, err = nmActivateConnection(cpath, devPath)
@@ -542,9 +679,9 @@ func (m *Manager) doDisconnectDevice(devPath dbus.ObjectPath) (err error) {
 		return
 	}
 
-	devState, _ := nmDev.State().Get(0)
+	devState, _ := nmDev.Device().State().Get(0)
 	if isDeviceStateInActivating(devState) {
-		err = nmDev.Disconnect(0)
+		err = nmDev.Device().Disconnect(0)
 		if err != nil {
 			logger.Error(err)
 		}
