@@ -127,9 +127,10 @@ func (h *LidSwitchHandler) doLidStateChanged(state bool) {
 		case powerActionTurnOffScreen:
 			m.doTurnOffScreen()
 		case powerActionDoNothing:
+			return
 		}
 
-		if !m.isWmBlackScreenActive() {
+		if lidCloseAction != powerActionTurnOffScreen && !m.isWmBlackScreenActive() {
 			m.setWmBlackScreenActive(true)
 		}
 	} else { // 开盖
@@ -146,6 +147,7 @@ func (h *LidSwitchHandler) doLidStateChanged(state bool) {
 		if m.isWmBlackScreenActive() {
 			m.setWmBlackScreenActive(false)
 		}
+		m.setDPMSModeOn()
 	}
 }
 
