@@ -91,6 +91,9 @@ type Manager struct {
 	cursorMask            uint32
 
 	mu sync.Mutex
+
+	CursorX               int32
+	CursorY               int32
 }
 
 const (
@@ -167,6 +170,8 @@ func (m *Manager) listenGlobalCursorPressed() error {
 			key := sig.Body[0].(uint32)
 			x := sig.Body[1].(uint32)
 			y := sig.Body[2].(uint32)
+			m.CursorX = int32(x)
+			m.CursorY = int32(y)
 			if key == buttonLeft {
 				m.cursorMask |= uint32(uint32(1) << leftBit)
 				key = x11BtnLeft
@@ -199,6 +204,8 @@ func (m *Manager) listenGlobalCursorRelease() error {
 			key := sig.Body[0].(uint32)
 			x := sig.Body[1].(uint32)
 			y := sig.Body[2].(uint32)
+			m.CursorX = int32(x)
+			m.CursorY = int32(y)
 
 			if key == buttonLeft {
 				m.cursorMask &= ^(uint32(1) << leftBit)
@@ -231,6 +238,8 @@ func (m *Manager) listenGlobalCursorMove() error {
 		if len(sig.Body) > 1 {
 			x := sig.Body[0].(uint32)
 			y := sig.Body[1].(uint32)
+			m.CursorX = int32(x)
+			m.CursorY = int32(y)
 
 			//m.cursorMask |= (1 << cursorBit)
 			var hasPress = false
@@ -820,3 +829,32 @@ func (m *Manager) DebugGetPidAreasMap() (pidAreasMapJSON string, busErr *dbus.Er
 	}
 	return string(data), nil
 }
+
+func (m *Manager) listenGlobalAxisChanged() error {
+	sessionBus := m.service.Conn()
+	err := sessionBus.Object("com.deepin.daemon.KWayland",
+		"/com/deepin/daemon/KWayland/Output").AddMatchSignal("com.deepin.daemon.KWayland.Output", "AxisChanged").Err
+	if err != nil {
+		logger.Warning(err)
+		return err
+	}
+
+	m.sessionSigLoop.AddHandler(&dbusutil.SignalRule{
+		Name: "com.deepin.daemon.KWayland.Output.AxisChanged",
+	}, func(sig *dbus.Signal) {
+		if len(sig.Body) > 1 {
+			x := sig.Body[1].(float64)
+			up := 4
+			down := 5
+
+			if x < 0 {
+				m.handleButtonEvent(int32(up), true, m.CursorX, m.CursorY)
+				m.handleButtonEvent(int32(up), false, m.CursorX, m.CursorY)
+			} else {
+				m.handleButtonEvent(int32(down), true, m.CursorX, m.CursorY)
+				m.handleButtonEvent(int32(down), false, m.CursorX, m.CursorY)
+			}
+		}
+	})
+	return nil
+}
